import { request } from '@umijs/max';

export async function userPage(body) {
    return request('/admin/invest/users/page', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json;charset=UTF-8',
        },
        data: body || {},
    });
}


export async function shopLevel(body) {
    return request('/admin/invest/users/modify/info', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json;charset=UTF-8',
        },
        data: body || {},
    });
}

export async function modifyMoney(body) {
    return request('/admin/invest/users/modify/money', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json;charset=UTF-8',
        },
        data: body || {},
    });
}



export async function changePath(body) {
    return request('/admin/invest/users/changePath', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json;charset=UTF-8',
        },
        data: body || {},
    });
}
export async function shopCreate(body) {
    return request('/admin/invest/users/add', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json;charset=UTF-8',
        },
        data: body || {},
    });
}


